import { VSCodeVersion } from './download';
export interface TestOptions {
    /**
     * The VS Code executable being used for testing.
     *
     * If not passed, will use options.version for downloading a copy of
     * VS Code for testing. If `version` is not specified either, will
     * download and use latest stable release.
     */
    vscodeExecutablePath?: string;
    /**
     * The VS Code version to download. Default to latest stable version.
     */
    version?: VSCodeVersion;
    /**
     * Absolute path to the extension root. Must include a `package.json`
     * Extension Manifest.
     */
    extensionPath: string;
    /**
     * Absolute path to the test suite folder. Must include an `index.js` that
     * exports a test runner, such as:
     *
     * ```ts
     * import * as testRunner from 'vscode/lib/testrunner';
     * module.exports = testRunner;
     * ```
     */
    testRunnerPath: string;
    /**
     * Absolute path of the fixture workspace to launch for testing
     */
    testWorkspace: string;
    /**
     * A list of arguments passed to `code` executable.
     * See `code --help` for possible arguments.
     *
     * ```ts
     * [
     *   options.testWorkspace,
     *   '--extensionDevelopmentPath=' + options.extPath,
     *   '--extensionTestsPath=' + options.testPath,
     *   '--locale=en'
     * ];
     * ```
     */
    vscodeLaunchArgs?: string[];
}
export declare function runTests(options: TestOptions): Promise<number>;
